parse_order_status_report

Function parse_order_status_report 

pub fn parse_order_status_report(
    uo: &UnmatchedOrder,
    instrument_id: InstrumentId,
    account_id: AccountId,
    ts_event: UnixNanos,
    ts_init: UnixNanos,
) -> Result<OrderStatusReport>
Parses a streaming UnmatchedOrder into a Nautilus [OrderStatusReport].

Resolves the Nautilus order status from the Betfair streaming status plus matched/cancelled quantities.

Errors

Returns an error if price or quantity values cannot be converted.